@@ -11,7 +11,3 @@ def buscar_avatar(usuario):
     url = f'https://api.github.com/users/{usuario}'
     resp = requests.get(url)
     return resp.json()['avatar_url']
-
-
-if __name__ == '__main__':
-    print(buscar_avatar('aguiardafa'))
